# powderbooking-database
Database model for the Powderbooking application

## How to use
This database model is pushed to pypi to make it available for all microservices.

#### Push to pypi
1. build with: `python setup.py sdist`
2. push with: `twine upload dist/*`
    - insert your pypi credentials.
